"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MappedExceptionFilter = void 0;
const common_1 = require("@nestjs/common");
const rxjs_1 = require("rxjs");
const mapped_exception_errors_1 = require("../core/mapped-exception.errors");
const mapped_exception_error_class_1 = require("../core/mapped-exception-error.class");
let MappedExceptionFilter = (() => {
    var MappedExceptionFilter_1;
    let MappedExceptionFilter = MappedExceptionFilter_1 = class MappedExceptionFilter {
        catch(exception, host) {
            const ctx = host.switchToHttp();
            const response = ctx.getResponse();
            const request = ctx.getRequest();
            const { status = common_1.HttpStatus.INTERNAL_SERVER_ERROR, message, code, } = this.getStatusAndMessage(exception);
            const contextType = host.getType();
            if (contextType === 'http') {
                return this.handleRestContext(request, response, status, message, code);
            }
            if (contextType === 'rpc') {
                return this.handleRpcContext(code, message);
            }
        }
        getStatusAndMessage(exception) {
            if (exception instanceof mapped_exception_error_class_1.MappedExceptionError) {
                const { code, message, statusCode } = exception.exception;
                return {
                    code: code.toString(),
                    message: `${message}`,
                    status: statusCode,
                };
            }
            if (exception instanceof common_1.HttpException) {
                return {
                    code: MappedExceptionFilter_1.getCodeFromHttpException(exception),
                    message: exception.message,
                    status: exception.getStatus(),
                };
            }
            return {
                code: mapped_exception_errors_1.DEFAULT_EXCEPTIONS.DEFAULT.code.toString(),
                message: exception.message,
                status: common_1.HttpStatus.INTERNAL_SERVER_ERROR,
            };
        }
        handleRestContext(request, response, status, message, code) {
            return response.code(status).send({
                message,
                code,
                statusCode: status,
                timestamp: new Date().toISOString(),
                path: request.url,
            });
        }
        handleRpcContext(code, message = '') {
            return rxjs_1.throwError(new Error(`${message} [${code}]`));
        }
        static getCodeFromHttpException(exception) {
            if (exception instanceof common_1.BadRequestException) {
                return mapped_exception_errors_1.DEFAULT_EXCEPTIONS.VALIDATION.DEFAULT.code.toString();
            }
            return mapped_exception_errors_1.DEFAULT_EXCEPTIONS.DEFAULT.code.toString();
        }
        static graphqlFormatError(error) {
            if (error instanceof mapped_exception_error_class_1.MappedExceptionError) {
                return error.exception || mapped_exception_errors_1.DEFAULT_EXCEPTIONS.DEFAULT;
            }
            if (error instanceof common_1.HttpException) {
                return {
                    code: this.getCodeFromHttpException(error),
                    message: error.message,
                    status: error.getStatus(),
                };
            }
            return {
                code: mapped_exception_errors_1.DEFAULT_EXCEPTIONS.DEFAULT.code.toString(),
                message: error.message,
                status: common_1.HttpStatus.INTERNAL_SERVER_ERROR,
            };
        }
    };
    MappedExceptionFilter = MappedExceptionFilter_1 = __decorate([
        common_1.Catch()
    ], MappedExceptionFilter);
    return MappedExceptionFilter;
})();
exports.MappedExceptionFilter = MappedExceptionFilter;
//# sourceMappingURL=mapped-exception.filter.js.map